Converter Tools
===============

.. code:: shell

    $ pip install km3pipe

    $ tohdf5 --aa-format=jevt_jgandalf some_jgandalf.aa.root

    $ tohdf5 --aa-format=ancient_recolns \
      --aa-lib=$SPS/lquinn/sandbox/aa-recoLNSlowE-prod2016/bin/reco_v0r9_standalone.so \
      some_recolns.root

    $ hdf2root foo.h5
